==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Button.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ButtonBase } from "./ButtonBase";
import { ButtonVariant_$type } from "./ButtonVariant";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var Button = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(Button.prototype, "v", {
        get: function () {
            var ret_ = this.h.m("variant");
            ret_ = enumGetBox(ButtonVariant_$type, EnumUtil.getEnumValue(ButtonVariant_$type, this.h.f(ButtonVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonVariant_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Button.$t = markType(Button, 'Button', ButtonBase.$);
    return Button;
}(ButtonBase));
export { Button };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Button.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ButtonBase } from "./ButtonBase";
import { ButtonVariant_$type } from "./ButtonVariant";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var Button = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(Button.prototype, "v", {
        get: function () {
            var ret_ = this.h.n("variant");
            ret_ = enumGetBox(ButtonVariant_$type, EnumUtil.getEnumValue(ButtonVariant_$type, this.h.f(ButtonVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ButtonVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Button.$t = markType(Button, 'Button', ButtonBase.$);
    return Button;
}(ButtonBase));
export { Button };
